pub struct DeploymentConfig {
pub max_nodes: usize,
pub max_stations_per_node: usize,
pub stale_after_ticks: u64,
}Expand description
Deployment route table configuration.
Fields
max_nodes: usizeMaximum registered nodes.
max_stations_per_node: usizeMaximum stations accepted by one node unless the node advertises a lower capacity.
stale_after_ticks: u64Ticks without heartbeat before a node is considered stale.