pub enum CellMigrationError {
Entity(EntityMigrationError),
MissingTargetRecord(EntityId),
MissingSourceRecord(EntityId),
}Expand description
Cell-level migration error.
Variants
Entity(EntityMigrationError)
Entity migration failed.
MissingTargetRecord(EntityId)
Target owner record was not found after a successful migration.
MissingSourceRecord(EntityId)
Source ghost record was not found after a successful migration.