pub enum CommandDispatchTransportError<E> {
Transport(E),
Encode(BinaryEncodeError),
Decode(BinaryDecodeError),
UnexpectedFrame,
EndpointMismatch {
packet_source: StationId,
packet_target: StationId,
dispatch_target: StationId,
},
MissingQueue(StationId),
Queue(CommandQueueError),
}Expand description
Error produced while bridging command dispatch frames through station packet transport.
Variants
Transport(E)
Underlying station transport failed.
Encode(BinaryEncodeError)
Wire encoding failed.
Decode(BinaryDecodeError)
Wire decoding failed.
UnexpectedFrame
Packet decoded as a non-command-dispatch frame.
EndpointMismatch
Packet envelope and decoded dispatch frame disagreed about the target.
Fields
MissingQueue(StationId)
Target station queue was not registered.
Queue(CommandQueueError)
Target station queue rejected the command.