pub struct CellMigrationExecutor;Expand description
Executes cell-level ownership migration using station-local indexes.
Implementations
Sourceimpl CellMigrationExecutor
impl CellMigrationExecutor
Sourcepub fn migrate_cells(
stations: &mut StationSet,
source_index: &mut CellIndex,
target_index: &mut CellIndex,
source_station: StationId,
target_station: StationId,
cells: &[CellCoord3],
ghost_ttl_ticks: u64,
) -> Result<CellMigrationReport, CellMigrationError>
pub fn migrate_cells( stations: &mut StationSet, source_index: &mut CellIndex, target_index: &mut CellIndex, source_station: StationId, target_station: StationId, cells: &[CellCoord3], ghost_ttl_ticks: u64, ) -> Result<CellMigrationReport, CellMigrationError>
Migrates owned entities found in cells from source station to target station.
Sourcepub fn migrate_cells_into(
stations: &mut StationSet,
source_index: &mut CellIndex,
target_index: &mut CellIndex,
source_station: StationId,
target_station: StationId,
cells: &[CellCoord3],
ghost_ttl_ticks: u64,
scratch: &mut CellMigrationScratch,
report: &mut CellMigrationReport,
) -> Result<(), CellMigrationError>
pub fn migrate_cells_into( stations: &mut StationSet, source_index: &mut CellIndex, target_index: &mut CellIndex, source_station: StationId, target_station: StationId, cells: &[CellCoord3], ghost_ttl_ticks: u64, scratch: &mut CellMigrationScratch, report: &mut CellMigrationReport, ) -> Result<(), CellMigrationError>
Migrates cells using caller-owned reusable working and report storage.
The report is reset before processing. As with Self::migrate_cells,
an error may occur after earlier entities have already migrated.