pub struct CellMigrationReport {
pub source_station: StationId,
pub target_station: StationId,
pub scanned_cells: Vec<CellCoord3>,
pub entity_migrations: Vec<EntityMigrationReport>,
pub skipped_missing_handles: usize,
pub skipped_non_owned: usize,
pub skipped_duplicate_entities: usize,
}Expand description
Result of migrating entities indexed by moved cells.
Fields
source_station: StationIdSource station.
target_station: StationIdTarget station.
scanned_cells: Vec<CellCoord3>Cells scanned for owner entities.
entity_migrations: Vec<EntityMigrationReport>Entity migrations that were committed.
skipped_missing_handles: usizeCandidate handles that no longer resolved to an entity.
skipped_non_owned: usizeCandidate entities skipped because they were ghosts or non-authoritative.
skipped_duplicate_entities: usizeDuplicate candidate entities skipped after first occurrence.