pub struct CellOwnershipTable { /* private fields */ }Expand description
Dynamic ownership table for fixed 3D cells.
Implementations
Sourceimpl CellOwnershipTable
impl CellOwnershipTable
Sourcepub fn assign(
&mut self,
cell: CellCoord3,
station_id: StationId,
) -> Option<StationId>
pub fn assign( &mut self, cell: CellCoord3, station_id: StationId, ) -> Option<StationId>
Assigns one cell to a station and returns the previous owner.
Sourcepub fn owner_of(&self, cell: CellCoord3) -> Option<StationId>
pub fn owner_of(&self, cell: CellCoord3) -> Option<StationId>
Returns the current owner for one cell.
Sourcepub fn apply_split(
&mut self,
proposal: &SplitProposal,
target_station: StationId,
) -> CellOwnershipUpdate
pub fn apply_split( &mut self, proposal: &SplitProposal, target_station: StationId, ) -> CellOwnershipUpdate
Applies a split proposal by assigning all proposed cells to target_station.
Sourcepub fn apply_split_into(
&mut self,
proposal: &SplitProposal,
target_station: StationId,
update: &mut CellOwnershipUpdate,
)
pub fn apply_split_into( &mut self, proposal: &SplitProposal, target_station: StationId, update: &mut CellOwnershipUpdate, )
Applies a split into caller-owned reusable update storage.