pub struct ClientTransportConfig {
pub client_id: ClientId,
pub server_id: ClientId,
pub expected_source: Option<ClientId>,
}Expand description
Low-level client transport bridge configuration.
Fields
client_id: ClientIdLocal client id expected inside client-bound frames.
server_id: ClientIdRemote server/gateway id used as the transport packet target for commands.
expected_source: Option<ClientId>Expected remote sender identity when the transport can identify it.
Implementations