ClientTransportStats

Struct ClientTransportStats 

pub struct ClientTransportStats {
Show 13 fields pub commands_sent: usize, pub command_bytes_sent: usize, pub packets_received: usize, pub bytes_received: usize, pub command_acks_received: usize, pub replication_frames_received: usize, pub barrier_frames_received: usize, pub frames_rejected_decode: usize, pub frames_rejected_unexpected: usize, pub frames_rejected_source: usize, pub frames_rejected_target: usize, pub entities_received: usize, pub components_received: usize,
}
Low-level client transport bridge statistics.

Fields

commands_sent: usize

Command frames encoded and submitted to transport.

command_bytes_sent: usize

Command bytes submitted to transport.

packets_received: usize

Packets consumed from transport.

bytes_received: usize

Bytes consumed from transport.

command_acks_received: usize

Command ACK frames decoded and accepted.

replication_frames_received: usize

Replication frames decoded and accepted.

barrier_frames_received: usize

Barrier frames decoded and accepted.

frames_rejected_decode: usize

Packets rejected by wire decoding.

frames_rejected_unexpected: usize

Packets rejected because they were not client-bound frames.

frames_rejected_source: usize

Packets rejected because the transport source did not match.

frames_rejected_target: usize

Packets rejected because the frame target did not match this client.

entities_received: usize

Entity deltas received in replication frames.

components_received: usize

Component deltas received in replication frames.