pub struct CommandDispatchTransportBridge { /* private fields */ }Expand description
Bridge between stamped command envelopes and bounded station packet transport.
Implementations
Sourceimpl CommandDispatchTransportBridge
impl CommandDispatchTransportBridge
Sourcepub const fn stats(&self) -> CommandDispatchTransportStats
pub const fn stats(&self) -> CommandDispatchTransportStats
Returns bridge statistics.
Sourcepub fn send_envelope<T>(
&mut self,
transport: &mut T,
source_station: StationId,
target_station: StationId,
command: &CommandEnvelope,
) -> Result<(), CommandDispatchTransportError<T::Error>>where
T: StationTransportSink,
pub fn send_envelope<T>(
&mut self,
transport: &mut T,
source_station: StationId,
target_station: StationId,
command: &CommandEnvelope,
) -> Result<(), CommandDispatchTransportError<T::Error>>where
T: StationTransportSink,
Encodes and sends a stamped command envelope to a station node.
Sourcepub fn send_frame<T>(
&mut self,
transport: &mut T,
source_station: StationId,
frame: &CommandDispatchFrame,
) -> Result<(), CommandDispatchTransportError<T::Error>>where
T: StationTransportSink,
pub fn send_frame<T>(
&mut self,
transport: &mut T,
source_station: StationId,
frame: &CommandDispatchFrame,
) -> Result<(), CommandDispatchTransportError<T::Error>>where
T: StationTransportSink,
Encodes and sends a command dispatch frame to its target station.
Sourcepub fn pump_target<T>(
&mut self,
transport: &mut T,
station_queues: &mut BTreeMap<StationId, CommandQueues>,
target_station: StationId,
max_packets: usize,
ingress: CommandIngress,
) -> Result<CommandDispatchPumpReport, CommandDispatchTransportError<T::Error>>where
T: StationTransportReceiver,
pub fn pump_target<T>(
&mut self,
transport: &mut T,
station_queues: &mut BTreeMap<StationId, CommandQueues>,
target_station: StationId,
max_packets: usize,
ingress: CommandIngress,
) -> Result<CommandDispatchPumpReport, CommandDispatchTransportError<T::Error>>where
T: StationTransportReceiver,
Receives up to max_packets for target_station, decodes command
dispatch frames, and enqueues stamped commands into station_queues.