pub struct GatewayCommandPipeline { /* private fields */ }Expand description
Business-agnostic gateway command frame pipeline.
Implementations
Sourceimpl GatewayCommandPipeline
impl GatewayCommandPipeline
Sourcepub fn new(config: GatewayCommandPipelineConfig) -> Self
pub fn new(config: GatewayCommandPipelineConfig) -> Self
Creates a pipeline.
Sourcepub const fn config(&self) -> GatewayCommandPipelineConfig
pub const fn config(&self) -> GatewayCommandPipelineConfig
Returns configuration.
Sourcepub const fn stats(&self) -> GatewayCommandPipelineStats
pub const fn stats(&self) -> GatewayCommandPipelineStats
Returns statistics.
Sourcepub fn process(
&mut self,
gateway: &mut GatewaySessionTable,
station_queues: &mut BTreeMap<StationId, CommandQueues>,
input: &[u8],
now: Tick,
ingress: CommandIngress,
) -> GatewayCommandPipelineReport
pub fn process( &mut self, gateway: &mut GatewaySessionTable, station_queues: &mut BTreeMap<StationId, CommandQueues>, input: &[u8], now: Tick, ingress: CommandIngress, ) -> GatewayCommandPipelineReport
Processes one decoded-transport command packet and optionally produces an encoded command ACK.
Sourcepub fn dispatch(
&mut self,
gateway: &mut GatewaySessionTable,
deployment: &DeploymentRouteTable,
input: &[u8],
now: Tick,
) -> GatewayCommandPipelineReport
pub fn dispatch( &mut self, gateway: &mut GatewaySessionTable, deployment: &DeploymentRouteTable, input: &[u8], now: Tick, ) -> GatewayCommandPipelineReport
Decodes and admits one command packet, then resolves a deployment route for external node dispatch without touching local station queues.