pub struct ReplicationReceiveStats {
pub packets_received: usize,
pub bytes_received: usize,
pub frames_received: usize,
pub frames_rejected_decode: usize,
pub frames_rejected_unexpected: usize,
pub frames_rejected_source: usize,
pub frames_rejected_target: usize,
pub entities_received: usize,
pub components_received: usize,
}Expand description
Replication receive bridge statistics.
Fields
packets_received: usizePackets consumed from client transport.
bytes_received: usizeBytes consumed from client transport.
frames_received: usizeReplication frames decoded and accepted.
frames_rejected_decode: usizePackets rejected by wire decoding.
frames_rejected_unexpected: usizePackets rejected because they were not replication frames.
frames_rejected_source: usizePackets rejected because the transport source did not match.
frames_rejected_target: usizePackets rejected because the frame target did not match this client.
entities_received: usizeEntity deltas received.
components_received: usizeComponent deltas received.