pub struct ReplicationTransportConfig {
pub budget: ReplicationBudget,
pub send_empty_frames: bool,
}Expand description
Client replication transport bridge configuration.
Fields
budget: ReplicationBudgetPlanner budget used for every viewer unless the caller builds frames manually.
send_empty_frames: boolWhether to send replication frames with no encoded entity deltas.