pub struct ReplicationTransportReport {
pub client_id: ClientId,
pub selected_entities: usize,
pub encoded_entities: usize,
pub encoded_components: usize,
pub estimated_plan_bytes: usize,
pub skipped_by_budget: usize,
pub skipped_by_cadence: usize,
pub skipped_by_frame_bytes: usize,
pub bytes_sent: usize,
pub sent: bool,
}Expand description
Result of one viewer replication send attempt.
Fields
client_id: ClientIdTarget client.
selected_entities: usizeCandidate entities selected by the replication planner.
encoded_entities: usizeEntity deltas encoded into the frame.
encoded_components: usizeComponent deltas encoded into the frame.
estimated_plan_bytes: usizeEstimated bytes from the replication planner.
skipped_by_budget: usizeCandidate entities skipped because the planner budget was exhausted.
skipped_by_cadence: usizeCandidate entities skipped because cadence had not elapsed.
skipped_by_frame_bytes: usizeEntities rolled back because the concrete frame byte budget filled.
bytes_sent: usizeEncoded wire bytes submitted to transport.
sent: boolWhether a frame was sent.