pub struct ReplicationTransportStats {
pub viewers_planned: usize,
pub frames_skipped_empty: usize,
pub frames_sent: usize,
pub bytes_sent: usize,
pub packet_capacity_hint_bytes: usize,
pub entities_selected: usize,
pub entities_skipped_by_budget: usize,
pub entities_skipped_by_cadence: usize,
pub entities_encoded: usize,
pub components_encoded: usize,
pub entities_skipped_by_frame_bytes: usize,
}Expand description
Client replication transport bridge statistics.
Fields
viewers_planned: usizeViewer queries planned.
frames_skipped_empty: usizeFrames skipped because they had no encoded entity deltas.
frames_sent: usizeFrames encoded and sent to client transport.
bytes_sent: usizeBytes sent through client transport.
packet_capacity_hint_bytes: usizeInitial packet byte capacity requested from bounded wire hints.
entities_selected: usizeEntities selected by AOI planning.
entities_skipped_by_budget: usizeEntities skipped by replication planner budget.
entities_skipped_by_cadence: usizeEntities skipped by replication planner cadence.
entities_encoded: usizeEntity deltas encoded into replication frames.
components_encoded: usizeComponent deltas encoded into replication frames.
entities_skipped_by_frame_bytes: usizeEntities rolled back because the concrete frame byte budget filled.