SplitScheduleView

Struct SplitScheduleView 

pub struct SplitScheduleView<'a> {
    pub decisions: &'a [HotspotDecision],
    pub actions: &'a [SplitAction],
    pub skipped_no_target: usize,
    pub skipped_no_cells: usize,
    pub skipped_cooldown: usize,
    pub skipped_target_severity: usize,
    pub skipped_target_capacity: usize,
    pub skipped_insufficient_improvement: usize,
}
Borrowed split schedule produced from reusable scheduler output slots.

Fields

decisions: &'a [HotspotDecision]

Hotspot decisions in input sample order.

actions: &'a [SplitAction]

Admitted split actions in deterministic source order.

skipped_no_target: usize

Hot stations skipped because no distinct target existed.

skipped_no_cells: usize

Hot stations skipped because no cells were proposed.

skipped_cooldown: usize

Hot stations skipped because source station is inside split cooldown.

skipped_target_severity: usize

Hot stations skipped because all targets were too warm or hot.

skipped_target_capacity: usize

Hot stations skipped because target capacity would be exceeded.

skipped_insufficient_improvement: usize

Hot stations skipped because target score improvement was too small.