SplitSchedulerConfig

Struct SplitSchedulerConfig 

pub struct SplitSchedulerConfig {
    pub thresholds: HotspotThresholds,
    pub max_actions_per_pass: usize,
    pub max_cells_per_action: usize,
    pub ghost_ttl_ticks: u64,
    pub min_score_improvement: u64,
    pub max_target_score_after_move: u64,
    pub split_cooldown_ticks: u64,
    pub allow_warm_targets: bool,
}
Automatic split scheduler configuration.

Fields

thresholds: HotspotThresholds

Hotspot thresholds.

max_actions_per_pass: usize

Maximum split actions to create per scheduling pass.

max_cells_per_action: usize

Maximum cells to move in each split action.

ghost_ttl_ticks: u64

Source ghost TTL used during migration execution.

min_score_improvement: u64

Minimum load-score gap required between source and target.

max_target_score_after_move: u64

Maximum permitted target load score after moved cell pressure is added.

split_cooldown_ticks: u64

Ticks a source station must wait before another split can be planned.

allow_warm_targets: bool

Whether warm target stations may receive split cells.