pub struct SplitSchedulerState { /* private fields */ }Expand description
Mutable planning state for conservative split scheduling.
Implementations
Sourceimpl SplitSchedulerState
impl SplitSchedulerState
Sourcepub fn last_split_at(&self, station_id: StationId) -> Option<Tick>
pub fn last_split_at(&self, station_id: StationId) -> Option<Tick>
Returns the last split tick for a source station.
Sourcepub fn record_action(&mut self, action: &SplitAction, tick: Tick)
pub fn record_action(&mut self, action: &SplitAction, tick: Tick)
Records one executed or externally accepted split action.
Sourcepub fn record_schedule(&mut self, schedule: &SplitSchedule, tick: Tick)
pub fn record_schedule(&mut self, schedule: &SplitSchedule, tick: Tick)
Records all actions in a schedule at the same tick.
Sourcepub fn record_schedule_view(
&mut self,
schedule: SplitScheduleView<'_>,
tick: Tick,
)
pub fn record_schedule_view( &mut self, schedule: SplitScheduleView<'_>, tick: Tick, )
Records all actions from a borrowed reusable schedule view.