StationEventTransportBridge

Struct StationEventTransportBridge 

pub struct StationEventTransportBridge { /* private fields */ }
Bridge between typed station events and bounded station packet transport.

Implementations

Source

impl StationEventTransportBridge

pub const fn stats(&self) -> StationEventTransportStats

Returns bridge statistics.

pub fn send_event<T>( &mut self, transport: &mut T, event: &StationEvent, ) -> Result<(), StationEventTransportError<T::Error>>

Encodes and sends one station event through the station transport.

pub fn pump_target<T>( &mut self, transport: &mut T, router: &mut EventRouter, target_station: StationId, max_packets: usize, ) -> Result<StationEventPumpReport, StationEventTransportError<T::Error>>

Receives up to max_packets for target_station, decodes station events, and routes them into router.