pub struct ClientTransportStats {Show 13 fields
pub commands_sent: usize,
pub command_bytes_sent: usize,
pub packets_received: usize,
pub bytes_received: usize,
pub command_acks_received: usize,
pub replication_frames_received: usize,
pub barrier_frames_received: usize,
pub frames_rejected_decode: usize,
pub frames_rejected_unexpected: usize,
pub frames_rejected_source: usize,
pub frames_rejected_target: usize,
pub entities_received: usize,
pub components_received: usize,
}Expand description
Low-level client transport bridge statistics.
Fields
commands_sent: usizeCommand frames encoded and submitted to transport.
command_bytes_sent: usizeCommand bytes submitted to transport.
packets_received: usizePackets consumed from transport.
bytes_received: usizeBytes consumed from transport.
command_acks_received: usizeCommand ACK frames decoded and accepted.
replication_frames_received: usizeReplication frames decoded and accepted.
barrier_frames_received: usizeBarrier frames decoded and accepted.
frames_rejected_decode: usizePackets rejected by wire decoding.
frames_rejected_unexpected: usizePackets rejected because they were not client-bound frames.
frames_rejected_source: usizePackets rejected because the transport source did not match.
frames_rejected_target: usizePackets rejected because the frame target did not match this client.
entities_received: usizeEntity deltas received in replication frames.
components_received: usizeComponent deltas received in replication frames.