pub struct StationEventTransportBridge { /* private fields */ }Expand description
Bridge between typed station events and bounded station packet transport.
Implementations
Sourceimpl StationEventTransportBridge
impl StationEventTransportBridge
Sourcepub const fn stats(&self) -> StationEventTransportStats
pub const fn stats(&self) -> StationEventTransportStats
Returns bridge statistics.
Sourcepub fn send_event<T>(
&mut self,
transport: &mut T,
event: &StationEvent,
) -> Result<(), StationEventTransportError<T::Error>>where
T: StationTransportSink,
pub fn send_event<T>(
&mut self,
transport: &mut T,
event: &StationEvent,
) -> Result<(), StationEventTransportError<T::Error>>where
T: StationTransportSink,
Encodes and sends one station event through the station transport.
Sourcepub fn pump_target<T>(
&mut self,
transport: &mut T,
router: &mut EventRouter,
target_station: StationId,
max_packets: usize,
) -> Result<StationEventPumpReport, StationEventTransportError<T::Error>>where
T: StationTransportReceiver,
pub fn pump_target<T>(
&mut self,
transport: &mut T,
router: &mut EventRouter,
target_station: StationId,
max_packets: usize,
) -> Result<StationEventPumpReport, StationEventTransportError<T::Error>>where
T: StationTransportReceiver,
Receives up to max_packets for target_station, decodes station
events, and routes them into router.